@@ -100,10 +100,10 @@ as.disk <- function(x, na.rm = FALSE) {
         unique() %pm>%
         sort() %pm>%
         vector_and(quotes = TRUE)
-      warning_(na_after - na_before, " results truncated (",
+      warning_("in `as.disk()`: ", na_after - na_before, " results truncated (",
                round(((na_after - na_before) / length(x)) * 100),
                "%) that were invalid disk zones: ",
-               list_missing, call = FALSE)
+               list_missing)
     }
   }
   set_clean_class(as.integer(x),
