@@ -95,7 +95,7 @@ rsi_calc <- function(...,
   }
   
   if (is.null(x)) {
-    warning_("argument is NULL (check if columns exist): returning NA", call = FALSE)
+    warning_("argument is NULL (check if columns exist): returning NA")
     if (as_percent == TRUE) {
       return(NA_character_)
     } else {
