@@ -39,6 +39,7 @@ if (AMR:::pkg_is_available("ggplot2")) {
 }
 expect_stdout(print(as.rsi(c("S", "I", "R"))))
 expect_equal(as.character(as.rsi(c(1:3))), c("S", "I", "R"))
+expect_equal(as.character(as.rsi(c(1:3))), c("S", "I", "R"))
 expect_equal(suppressWarnings(as.logical(as.rsi("INVALID VALUE"))), NA)
 expect_equal(summary(as.rsi(c("S", "R"))),
              structure(c("Class" = "rsi",
@@ -63,7 +64,7 @@ if (AMR:::pkg_is_available("dplyr", min_version = "1.0.0")) {
   
   expect_stdout(print(tibble(ab = as.rsi("S"))))
 }
-if (AMR:::pkg_is_available("skimr")) {
+if (AMR:::pkg_is_available("skimr", min_version = "2.0.0")) {
   expect_inherits(skim(example_isolates),
                   "data.frame")
   if (AMR:::pkg_is_available("dplyr", min_version = "1.0.0")) {
@@ -75,6 +76,7 @@ if (AMR:::pkg_is_available("skimr")) {
   }
 }
 
+expect_equal(as.rsi(c("", "-", NA, "NULL")), c(NA_rsi_, NA_rsi_, NA_rsi_, NA_rsi_))
 
 # S. pneumoniae/ampicillin in EUCAST 2020: 0.5-2 ug/ml (R is only > 2)
 expect_equal(as.character(
